{ config, lib, pkgs, ... }:

let
  inherit (lib) mkIf mkMerge mkThenElse;
  annuaire = config.r6d.machines;
  currentMachine = annuaire."${config.networking.fqdn}";
  flags = currentMachine.configurationFlags;
in

mkIf flags.print {

  environment.systemPackages = with pkgs; [
    samba
    python310Packages.pysmbc
  ];
  services.samba.enable = true;
  # Services
  ## Enable CUPS to print documents.
  services.printing = {
    enable = true;
    drivers = [
      pkgs.samsung-unified-linux-driver
      pkgs.gutenprint
    ];
    # Suppression automatique des fichiers temporaires.
    # Par défaut, cups conserve une copie de ce qui a été imprimé
    # pas cool pour les mots de passe ou autre donnée sensible
    extraConf = ''
      PreserveJobHistory No
      PreserveJobFiles No
    '';
  };
  services.avahi.enable = true;
  services.avahi.nssmdns = true;
}
